@@ -1471,9 +1471,18 @@ sweep_string_in_operand (insn, loc, sweep_offset, sweep_size)
       break;
 
     case CALL_PLACEHOLDER:
-      sweep_string_use_of_insns (XEXP (x, 0), sweep_offset, sweep_size);
-      sweep_string_use_of_insns (XEXP (x, 1), sweep_offset, sweep_size);
-      sweep_string_use_of_insns (XEXP (x, 2), sweep_offset, sweep_size);
+      for (i = 0; i < 3; i++)
+	{
+	  rtx seq = XEXP (x, i);
+	  if (seq)
+	    {
+	      push_to_sequence (seq);
+	      sweep_string_use_of_insns (XEXP (x, i),
+					 sweep_offset, sweep_size);
+	      XEXP (x, i) = get_insns ();
+	      end_sequence ();
+	    }
+	}
       break;
 
     default:
@@ -1645,9 +1654,17 @@ change_arg_use_in_operand (x, orig, new, size)
       break;
 
     case CALL_PLACEHOLDER:
-      change_arg_use_of_insns_2 (XEXP (x, 0), orig, new, size);
-      change_arg_use_of_insns_2 (XEXP (x, 1), orig, new, size);
-      change_arg_use_of_insns_2 (XEXP (x, 2), orig, new, size);
+      for (i = 0; i < 3; i++)
+	{
+	  rtx seq = XEXP (x, i);
+	  if (seq)
+	    {
+	      push_to_sequence (seq);
+	      change_arg_use_of_insns_2 (XEXP (x, i), orig, new, size);
+	      XEXP (x, i) = get_insns ();
+	      end_sequence ();
+	    }
+	}
       break;
 
     default:
@@ -1782,9 +1799,17 @@ validate_operand_of_varrefs (insn, loc)
       
 
     case CALL_PLACEHOLDER:
-      validate_insns_of_varrefs (XEXP (x, 0));
-      validate_insns_of_varrefs (XEXP (x, 1));
-      validate_insns_of_varrefs (XEXP (x, 2));
+      for (i = 0; i < 3; i++)
+	{
+	  rtx seq = XEXP (x, i);
+	  if (seq)
+	    {
+	      push_to_sequence (seq);
+	      validate_insns_of_varrefs (XEXP (x, i));
+	      XEXP (x, i) = get_insns ();
+	      end_sequence ();
+	    }
+	}
       break;
 
     default:
